//Extend arrays to have a contains method
if (!("contains" in Array.prototype)){
	Array.prototype.contains = function ( needle ) {
		var i = 0;
		for (i in this) {
			if (this[i] === needle)
			{
				return true;
			}
		}
		return false;
	};
}

//Start of closure
(function($){
		//Get all lists
		var lists = $('.prettyFileList');

		//Default settings
		var settings = {
			'searchBoxDefault' : "Search...",
			'filesPerPageDefault' : 3,
			'hideFilter' : false,
			'hideSort' : false,
			'hideSearch' : false
		};

		//Get all of the lists to upgrade to File Lists
		lists.each(
			function(index){
				//Create a new file list object for each one
				new FileList($(this),settings);
			}
		);

	//FUNCTIONS
	//case-insensitive version of :contains
	$.extend($.expr[":"], {
		"containsNC": function(elem, i, match, array) {
			return (elem.textContent || elem.innerText || "").toLowerCase().indexOf((match[3] || "").toLowerCase()) >= 0;
		}
	});

	//FileList Class
	//==========================
	//Params:
	//List: a list to be upgraded as a jQuery object
	//Settings (optional): a settings object
	function FileList(list,options){

		//Store this so we can access it inside sub scopes
		var thisFileList = this;

		//SETTINGS
		this.settings = {
			'searchBoxDefault' : "Search...",
			'filesPerPageDefault' : 3,
			'hideFilter' : false,
			'hideSort' : false,
			'hideSearch' : false
		};

		if ( options ) {
			$.extend( this.settings, options );
        }

		//Wrap the list in a styling div and Add neccesary classes
		list.wrap('<div class="prettyFileList" />');
		list.attr('class','prettyListItems unstyled');

		//get options from data attributes or settings
		this.hideFilterDef = list.data('hidefilter') !== undefined ? list.data('hidefilter') : this.settings.hideFilter;
		this.hideSearchDef = list.data('hidesearch') !== undefined ? list.data('hidesearch') : this.settings.hideSearch;
		this.hideSortDef = list.data('hidesort') !== undefined ? list.data('hidesort') : this.settings.hideSort;
		//Build the bar
		this.prettyFileBar = $('<div class="prettyFileBar clearfix"></div>');
		var barHtml = (this.hideFilterDef === false) ? '<a href="#" class="showFilterBtn float_right corePrettyStyle btn">Filter</a>' : '';//Add filter button
		barHtml = barHtml + (this.hideSortDef === false ? '<a href="#" class="showSortingBtn float_right corePrettyStyle btn">Sort</a>' : '');//Add filter button
		barHtml = barHtml + (this.hideSearchDef === false ? '<div class="prettyFileListSearch"><label style="display:none;">Search</label><input type="text" value="' + this.settings.searchBoxDefault +'" class="prettySearchValue"><a class="doPrettySearch btn corePrettyStyle">Go</a><a class="clearSearch btn corePrettyStyle hidden">Clear</a></div>' : '');//Add search

		//Loop all items and create an array of types found
		this.fileTypesArray = Array();

		//Regex to match file extensions
		this.fileExtRegex = /.+\.([^?]+)(\?|$)/;

		$('li a',list).each(function(){
			var linkItem = $(this);
			var fileExt = "";
			//If file ext not defined in data attribute
			if(linkItem.data('doctype') === undefined){
				var url = linkItem.attr('href');//Get the file link
				fileExt = url.match(thisFileList.fileExtRegex)[1];//Get the file extension
			}
			else{
				fileExt = linkItem.data('doctype');//Use the data attrib
			}

			if (fileExt === "docx"){fileExt = "doc";}//make doc and docx the same
			if (fileExt === "pptx"){fileExt = "ppt";}//make ppt and pptx the same
			if (fileExt === "xslx"){fileExt = "xsl";}//make xls and xlsx the same
			if (fileExt === "jpeg"){fileExt = "jpg";}//make jpeg and jpg the same
			if (fileExt === "mpeg"){fileExt = "mpg";}//make mpeg and mpg the same
			if (fileExt === "mp3"){fileExt = "ogg";}//make mp3 and ogg the same
			if (fileExt === "accdb"){fileExt = "mdb";}//make accdb and mdb the same

			//See if this is a new filetype, if it is add it to array
			if(!thisFileList.fileTypesArray.contains(fileExt)){
				thisFileList.fileTypesArray.push(fileExt);
			}

			linkItem.addClass(fileExt + ' prettylink corePrettyStyle');//Add
		});

		var filterList = '<div class="prettyFileFilters"><ul class="unstyled">';

		for(var i = 0; i < thisFileList.fileTypesArray.length; i++){
			filterList = filterList + '<li><a href="" data-filter-type="' + thisFileList.fileTypesArray[i] + '" class="'+ thisFileList.fileTypesArray[i] +'Filter ' +  thisFileList.fileTypesArray[i] + ' showing">' + thisFileList.fileTypesArray[i] +'</a></li>';
		}

		filterList = filterList + '</ul><p class="bar"><a href="#" class="cross">Close</a></p></div>';

		barHtml = barHtml + ((this.hideFilterDef === false) ? filterList : '');//Add filter box

		barHtml = barHtml + (this.hideSortDef === false ? '<div class="prettyFileSorting" style="' + (this.hideFilterDef === true ? 'right:0;' : '')  +'"><ul class="unstyled"><li><a href="" data-sort-type="bytitle">By Name</a></li><li><a href="" data-sort-type="bytype" class="">By Type</a></li></ul><p class="bar"><a href="#" class="cross">Close</a></p></div>' : '');//Add sort box, and move toright if filter hidden
		this.prettyFileBar.html(barHtml);//Add buttons to filter bar
		list.before(this.prettyFileBar);//Add filters etc
		list.before('<div style="display:none" class="prettyMessage"><span></span><a class="btn corePrettyStyle" href="#">Show all files</a></div>');//Add message box
		list.after('<div class="prettyPagination"><a href="#" class="pfl_next btn corePrettyStyle">Next &raquo;</a><span class="pagingInfo">Page <span class="currentPage"></span> of <span class="totalPages"></span></span><a href="#" class="pfl_prev btn disabled corePrettyStyle">&laquo; Prev</a></div>');//Add paging

		//Get all objects
		//JQUERY OBJECTS CACHE
		//DOM OBJECTS
		this.allFilesContainer = list.parent();

		//Message box
		this.messageBox = $('.prettyMessage',this.allFilesContainer);
		this.messageText = $('span',this.messageBox);
		//All files
		this.filteredFiles = $('.prettylink',this.allFilesContainer);
		//Working file list
		this.allFiles = this.filteredFiles.clone();
		//File container
		this.fileContainer = $('.prettyListItems',this.allFilesContainer);
		//Next and prev buttons
		this.nextButton = $('.pfl_next',this.allFilesContainer);
		this.prevButton = $('.pfl_prev',this.allFilesContainer);
		//Paging info
		this.pageAt = list.data('filesperpage') !== undefined ? list.data('filesperpage') : this.settings.filesPerPageDefault;
		this.paginationContainer = $('.prettyPagination',this.allFilesContainer);
		this.currentPageCounter = $('.currentPage',this.allFilesContainer);
		this.totalPageCounter = $('.totalPages',this.allFilesContainer);
		//Top bar
		this.searchAndFilterContainer = this.prettyFileBar;
		//Filters
		this.showFilterBtn = $('.showFilterBtn',this.allFilesContainer);
		this.filterLinksContainer = $('.prettyFileFilters',this.allFilesContainer);
		this.filterLinks = $('li a',this.filterLinksContainer);
		//Sorting
		this.showSortingBtn = $('.showSortingBtn',this.allFilesContainer);
		this.sortingLinksContainer = $('.prettyFileSorting',this.allFilesContainer);
		this.sortingLinks = $('.prettyFileSorting li a',this.allFilesContainer);

		//Search
		this.searchBoxContainer = $('.prettyFileListSearch',this.allFilesContainer);
		this.searchBox = $('.prettySearchValue',this.searchBoxContainer);
		this.searchButton = $('.doPrettySearch',this.searchBoxContainer);
		this.clearSearchButton = $('.clearSearch',this.searchBoxContainer);

		//VARIABLES
		this.currentPage = 0;
		//Total number of files
		this.totalFiles = this.filteredFiles.length;
		//Total pages
		this.totalPages = (Math.ceil(this.totalFiles / this.pageAt));

		//EVENTS
		//==========================================
		//Next and prev buttons only wired up if needed
		if(this.pageAt < this.totalFiles){
			//Next click
			this.nextButton.click(function(){
				if($(this).hasClass('disabled')){return false;}
				thisFileList.currentPage++;
				showHidePages(thisFileList);
				return false;
			});

			//Prev click
			this.prevButton.click(function()
			{
				if($(this).hasClass('disabled')){return false;}
				thisFileList.currentPage--;
				showHidePages(thisFileList);
				return false;
			});
		}

		//Filtering
		//Show filters
		this.showFilterBtn.click(function(){
			thisFileList.sortingLinksContainer.hide();
			thisFileList.filterLinksContainer.toggle();
			return false;
		});

		//Hide filters
		$('.cross',this.filterLinksContainer).click(function(){
			thisFileList.sortingLinksContainer.hide();
			thisFileList.filterLinksContainer.toggle();
			return false;
		});

		//Filter item clicked
		this.filterLinks.click(function(event){
			//Get the type we're looking for
			$(this).toggleClass('showing');
			//Get all types that are selected
			var typeToShow = $('.prettyFileFilters a.showing',thisFileList.allFilesContainer);
			var typesString = "";
			// [MNAKALAY MODIFICATION]
			var typeCount = typeToShow.length;
			if(typeCount > 0){
				$.each(typeToShow,function(index,element){
                        typesString += "." + $(this).data('filter-type');
                        if (index != typeCount - 1) {
                                typesString += ',';
                        }
                    });
				// [END MODIFICATION]

				//Delete all files
				thisFileList.filteredFiles.remove();
				//Reclone them in
				thisFileList.filteredFiles = thisFileList.allFiles.filter(typesString);

				if(thisFileList.filteredFiles.length === 0){
					showHideMessage("No files of selected type(s) found.",thisFileList);
				}
				else{

					thisFileList.fileContainer.append(thisFileList.filteredFiles);
					//Reset paging
					thisFileList.currentPage = 0;
					resetPaging(thisFileList);
					//Refilter
					showHidePages(thisFileList);
					//Clear any messages
					showHideMessage("",thisFileList);
				}
			}
			else{
				showHideMessage('No types selected.',thisFileList);
			}
			return false;
		});

			//Search
			//Show active state
			this.searchBox.focus(function(e){
				$(this).addClass("active");
				if($(this).val() === thisFileList.settings.searchBoxDefault){
					$(this).val("");
				}
			});

			//Clear active state
			this.searchBox.blur(function(e){
				$(this).removeClass("active");
				if($(this).val() === "") {
					$(this).val(thisFileList.settings.searchBoxDefault);
				}
			});

			//Fire search on enter key
			this.searchBox.keydown(function (e){
				if(e.keyCode === 13){
					thisFileList.searchButton.click();
				}
			});

			//search
			this.searchButton.click(function(){
				//Check for a search term
				if(thisFileList.searchBox.val() !== "" && thisFileList.searchBox.val() !== thisFileList.settings.searchBoxDefault){
					thisFileList.searchBox.removeClass("error");
					//Clear all files
					thisFileList.filteredFiles.remove();
					thisFileList.filteredFiles = thisFileList.allFiles.filter(':containsNC(' + thisFileList.searchBox.val() + ')');
					if(thisFileList.filteredFiles.length > 0){
						thisFileList.fileContainer.append(thisFileList.filteredFiles);
						thisFileList.currentPage = 0;
						resetPaging(thisFileList);
						//Refilter
						showHidePages(thisFileList);
						//Clear any messages
						showHideMessage("",thisFileList);
						thisFileList.clearSearchButton.removeClass('hidden');
					}
					else{
						thisFileList.clearSearchButton.removeClass('hidden');
						showHideMessage("No files found.",thisFileList);
					}
				}
				else{
						thisFileList.searchBox.addClass("error");
				}
			});

			//reset search
			this.clearSearchButton.click(function(){
				//Clear value
				thisFileList.searchBox.val("Search...");
				//Clear all
				resetWholeList(thisFileList);
			});

			//Show options
			this.showSortingBtn.click(function(){
				thisFileList.filterLinksContainer.hide();
				thisFileList.sortingLinksContainer.toggle();
				return false;
			});

			//Hide option
			$('.cross',this.sortingLinksContainer).click(function(){
				thisFileList.filterLinksContainer.hide();
				thisFileList.sortingLinksContainer.toggle();
				return false;
			});

				//Sorting
				this.sortingLinks.click(function(event){
					var clicked = $(this);
					//Get sort type
					var sortType = clicked.data("sort-type");
					var sortDirection = "";
					var sortLinks = thisFileList.sortingLinks;
					sortDirection = clicked.data("sort-direction");

					//Clear all direction classes
					sortLinks.attr('class','');

					//Get sort direction
					if(sortDirection === "" || sortDirection === undefined){
						//If no sort direction clear all
						sortLinks.data('sort-direction','');
						//Set to asc
						sortDirection = 'asc';
					}
					else{
						if(clicked.data('sort-direction') === 'asc'){
							sortDirection = 'dec';
						}
						else{
							sortDirection = 'asc';
						}
					}

					//Add the sort direction to the item
					clicked.data('sort-direction',sortDirection);
					clicked.addClass(sortDirection);

					//Clear all sort directions
					sortList(sortDirection,sortType,thisFileList);

					//Reset paging
					thisFileList.currentPage = 0;
					resetPaging(thisFileList);
					//Refilter
					showHidePages(thisFileList);
					//Clear any messages
					showHideMessage("",thisFileList);

					thisFileList.sortingLinksContainer.slideToggle();
					return false;
				});

				//Show all files button
				$('.btn',thisFileList.messageBox).click(
					function(){
						//Clear all
						resetWholeList(thisFileList);
						return false;
					}
				);

				//Set up first page
				//====================
				showHidePages(thisFileList);
	}
	//End FileList Class

	//Methods
	//==========================================
	//Show and hide error message
	function showHideMessage(message,thisFileList){
		$('span',thisFileList.messageBox).text(message);
		if(message.length > 0){
			//Get the filtered files again and then Delete all files
			thisFileList.filteredFiles.remove();
			//Reset paging
			thisFileList.currentPage = 0;
			//Total pages
			thisFileList.totalPages = 1;
			//Refilter
			showHidePages(thisFileList);
			//Show the error message
			thisFileList.messageBox.show();
		}
		else{
			thisFileList.messageBox.hide();
		}
	}

	//Show pages and paging
	function showHidePages(thisFileList){
		//Hide all
		thisFileList.filteredFiles.hide();

		//Show current page
		thisFileList.filteredFiles.filter(':lt(' + ((parseInt(thisFileList.currentPage) + 1)  * parseInt(thisFileList.pageAt)) + ')').css('display', 'block');
		thisFileList.filteredFiles.filter(':lt(' + (parseInt(thisFileList.currentPage) * parseInt(thisFileList.pageAt)) + ')').hide();

		//Remove loading
		thisFileList.fileContainer.removeClass('loading');
		//Set paging
		if(thisFileList.currentPage === 0){
			thisFileList.prevButton.addClass('disabled');
		}
		else{
			thisFileList.prevButton.removeClass('disabled');
		}
		if(thisFileList.currentPage === (thisFileList.totalPages - 1)){
			thisFileList.nextButton.addClass('disabled');
		}
		else{
			thisFileList.nextButton.removeClass('disabled');
		}

		//Update paging text

		if(thisFileList.totalPages > 1){
			thisFileList.paginationContainer.show();
			thisFileList.currentPageCounter.text(parseInt(thisFileList.currentPage) + 1);
			resetPaging(thisFileList);
		}
		else{
			//hide pages as not needed
			thisFileList.paginationContainer.hide();
		}
	}

	//RESET ALL
	function resetWholeList(thisFileList){
		//Clear all files
		thisFileList.filteredFiles.remove();
		thisFileList.filteredFiles = thisFileList.allFiles;
		thisFileList.fileContainer.append(thisFileList.filteredFiles);
		//Clear filters
		thisFileList.filterLinks.addClass('showing');
		//Reset paging
		thisFileList.currentPage = 0;
		resetPaging(thisFileList);
		//Refilter
		showHidePages(thisFileList);
		//Clear any messages
		showHideMessage("",thisFileList);
		//Hide clear button
		thisFileList.clearSearchButton.addClass('hidden');
	}

	//Reset paging
	function resetPaging(thisFileList){
		//Recalculate total pages
		thisFileList.totalPages = Math.ceil(thisFileList.filteredFiles.length / thisFileList.pageAt);
		$('.totalPages',thisFileList.allFilesContainer).text(thisFileList.totalPages);
	}

	//Sorting function
	function sortList(direction,sortType,thisFileList){
		thisFileList.filteredFiles.remove();

		//pick the sort type
		var sortAlg = direction + "_" + sortType;

		//pick the sort
		//Do switch because eval is evil ;)
		switch (sortAlg){
			case 'asc_bytype':
				thisFileList.filteredFiles = thisFileList.filteredFiles.sort(asc_bytype);
				break;
			case 'dec_bytype':
				thisFileList.filteredFiles = thisFileList.filteredFiles.sort(dec_bytype);
				break;
			case 'asc_bytitle':
				thisFileList.filteredFiles = thisFileList.filteredFiles.sort(asc_bytitle);
				break;
			case 'dec_bytitle':
				thisFileList.filteredFiles = thisFileList.filteredFiles.sort(dec_bytitle);
				break;
			default:
				thisFileList.filteredFiles = thisFileList.filteredFiles.sort(asc_bytype);
				break;
		}

		thisFileList.fileContainer.append(thisFileList.filteredFiles);
	}

	//TITLE SORT
	// accending sort
	function asc_bytitle(a, b){
      return $(a).text().toUpperCase().localeCompare($(b).text().toUpperCase());
      // return $(b).text() < $(a).text();
	}
	// decending sort
	function dec_bytitle(a, b){
      return $(b).text().toUpperCase().localeCompare($(a).text().toUpperCase());
      // return $(b).text() > $(a).text();
	}
	
	//TYPE SORT
	// accending sort
	//function asc_bytype(a, b){return ($(b).attr("class")) < ($(a).attr("class"));}
	// decending sort
	//function dec_bytype(a, b){return ($(b).attr("class")) > ($(a).attr("class"));}

	//TITLE SORT
	// accending sort
	//function asc_bytitle(a, b){return $(b).text() < $(a).text();}
	// decending sort
	//function dec_bytitle(a, b){return $(b).text() > $(a).text();}

})(jQuery);
//End of closure

